@@ -3,15 +3,14 @@ import click
 from markdrip.mods import generator as gen
 
 @click.command()
-@click.option("--output", "-o", help="Output destination file path")
-@click.option("--theme", "-t", default="github", help="Applicable CSS file name. Does not include extension.")
+@click.option("--output", default="./", help="Output destination file path")
+@click.option("--theme", default="github", help="Applicable CSS file name. Does not include extension.")
 
 @click.argument("target")
 def main(target, theme, output):
 
     mkup, filename = gen.markup(target)
     css = gen.load_css(theme)
-<<<<<<< Updated upstream
     if css != "\\[ERROR]/":
         if output == "./":
             output = filename + ".html"
@@ -19,12 +18,6 @@ def main(target, theme, output):
         gen.rendor(mkup, css, output)
 
 
-=======
-    if output == None:
-        output = target
-
-    gen.rendor(mkup, css, output)
->>>>>>> Stashed changes
 
 if __name__ == "__main__":
     main()
